OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Погрешна лозинка",
    "Saved" : "Сачувано",
    "No user supplied" : "Није наведен корисник",
    "Unable to change password" : "Не могу да променим лозинку",
    "Authentication error" : "Грешка при провери идентитета",
    "Wrong admin recovery password. Please check the password and try again." : "Погрешна администраторска лозинка опоравка. Проверите лозинку и покушајте поново.",
    "Federated Cloud Sharing" : "Здружено дељење у облаку",
    "A problem occurred, please check your log files (Error: %s)" : "Појавио се проблем. Проверите записнике (грешка: %s)",
    "Migration Completed" : "Пресељење завршено",
    "Group already exists." : "Група већ постоји.",
    "Unable to add group." : "Није могуће додати групу.",
    "Unable to delete group." : "Није могуће обрисати групу.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Појавио се проблем приликом слања е-поште. Проверите ваше поставке. (Грешка: %s)",
    "You need to set your user email before being able to send test emails." : "Морате поставити адресу е-поште пре слања тестне поруке.",
    "Invalid mail address" : "Неисправна е-адреса",
    "A user with that name already exists." : "Корисник са тим именом већ постоји.",
    "Unable to create user." : "Не могу да направим корисника.",
    "Unable to delete user." : "Не могу да обришем корисника.",
    "Unable to change full name" : "Не могу да променим пуно име",
    "Your full name has been changed." : "Ваше пуно име је промењено.",
    "Forbidden" : "Забрањено",
    "Invalid user" : "Неисправан корисник",
    "Unable to change mail address" : "Не могу да изменим е-адресу",
    "Email saved" : "Е-порука сачувана",
    "Your %s account was created" : "Ваш %s налог је направљен",
    "Couldn't remove app." : "Не могу да уклоним апликацију.",
    "Couldn't update app." : "Не могу да ажурирам апликацију.",
    "Add trusted domain" : "Додај поуздан домен",
    "Migration in progress. Please wait until the migration is finished" : "Пресељење је у току. Сачекајте док се не заврши",
    "Migration started …" : "Пресељење покренуто...",
    "Email sent" : "Порука је послата",
    "Official" : "Званичне",
    "All" : "Све",
    "Update to %s" : "Ажурирај на %s",
    "No apps found for your version" : "Нема апликација за вашу верзију",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Одобрене апликације су развили проверени програмери и апликације су прошле основне безбедносне провере. Оне се активно одржавају у репозиторијуму за апликације отвореног кода и њихови одржаватељи сматрају да су стабилне за уобичајену употребу.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ова апликација није проверена по питању безбедности и нова је или зна да буде нестабилна. Инсталирате је на сопствену одговорност.",
    "Error while disabling app" : "Грешка при искључивању апликације",
    "Disable" : "Искључи",
    "Enable" : "Укључи",
    "Error while enabling app" : "Грешка при укључивању апликације",
    "Updating...." : "Ажурирам…",
    "Error while updating app" : "Грешка при ажурирању апликације",
    "Updated" : "Ажурирано",
    "Approved" : "Одобрене",
    "Experimental" : "Експерименталне",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Дошло је до грешке. Отпремите АСКИ кодирани ПЕМ сертификат.",
    "Valid until {date}" : "Важи до {date}",
    "Delete" : "Обриши",
    "Select a profile picture" : "Изаберите слику профила",
    "Very weak password" : "Веома слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Осредња лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "Groups" : "Групе",
    "Unable to delete {objName}" : "Не могу да обришем {objName}",
    "A valid group name must be provided" : "Мора бити наведено исправно име групе",
    "deleted {groupName}" : "обрисана {groupName}",
    "undo" : "опозови",
    "never" : "никада",
    "deleted {userName}" : "обрисан {userName}",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Измена лозинке ће резултирати губитком података јер опорављање података није доступно за овог корисника",
    "A valid username must be provided" : "Морате унети исправно корисничко име",
    "A valid password must be provided" : "Морате унети исправну лозинку",
    "A valid email must be provided" : "Мора бити наведена исправна е-адреса",
    "Developer documentation" : "Програмерска документација",
    "Documentation:" : "Документација:",
    "User documentation" : "Корисничка документација",
    "Admin documentation" : "Администраторска документација",
    "Show description …" : "Прикажи опис…",
    "Hide description …" : "Сакриј опис…",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Апликација се не може инсталирати јер следеће зависности нису испуњене:",
    "Enable only for specific groups" : "Укључи само за одређене групе",
    "Common Name" : "Уобичајено име",
    "Valid until" : "Важи до",
    "Issued By" : "Издавач",
    "Valid until %s" : "Важи до %s",
    "Import root certificate" : "Увоз кореног сертификата",
    "Administrator documentation" : "Администраторска документација",
    "Online documentation" : "Документација на мрежи",
    "Forum" : "Форум",
    "Commercial support" : "Комерцијална подршка",
    "None" : "Ништа",
    "Login" : "Пријава",
    "Plain" : "Обичан",
    "NT LAN Manager" : "НТ ЛАН менаџер",
    "Email server" : "Сервер е-поште",
    "Open documentation" : "Отвори документацију",
    "Send mode" : "Режим слања",
    "Encryption" : "Шифровање",
    "From address" : "Са адресе",
    "mail" : "пошта",
    "Authentication method" : "Начин аутентификације",
    "Authentication required" : "Неопходна провера идентитета",
    "Server address" : "Адреса сервера",
    "Port" : "Порт",
    "Credentials" : "Акредитиви",
    "SMTP Username" : "СМТП корисничко име",
    "SMTP Password" : "СМТП лозинка",
    "Store credentials" : "Сачувај акредитиве",
    "Test email settings" : "Тестирај поставке е-поште",
    "Send email" : "Пошаљи е-пошту",
    "Server-side encryption" : "Шифровање на страни сервера",
    "Enable server-side encryption" : "Укључи шифровање на страни сервера",
    "Enable encryption" : "Укључи шифровање",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Шифрарски модул није учитан. Укључите га у менију апликација",
    "Select default encryption module:" : "Изаберите подразумевани шифрарски модул:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Морате да пребаците старе шифрарске кључеве (оунКлауд <= 8.0) на нови. Укључите „оунКлауд подразумевани шифрарски модул“ и покрените 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Морате да преселите шифрарске кључеве старог шифровања (оунКлауд <= 8.0) на нове.",
    "Start migration" : "Покрени пресељење",
    "Security & setup warnings" : "Безбедносна и упозорења поставе",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Омогућена је Само-читај конфигурација. То спречава постављање неке конфигурације преко веб-интерфејса. Осим тога, фајлу мора бити ручно омогућено уписивање код сваког освежавања.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
    "System locale can not be set to a one which supports UTF-8." : "Системски локалитет се не може поставити на неки који подржава УТФ-8",
    "Execute one task with each page loaded" : "Изврши један задатак са сваком учитаном страницом",
    "Version" : "Верзија",
    "Sharing" : "Дељење",
    "Allow apps to use the Share API" : "Дозвољава апликацијама да користе АПИ дељења",
    "Allow users to share via link" : "Дозволи корисницима да деле путем везе",
    "Allow public uploads" : "Дозволи јавна отпремања",
    "Enforce password protection" : "Захтевај заштиту лозинком",
    "Set default expiration date" : "Постави подразумевано време истека",
    "Expire after " : "Истиче након",
    "days" : "дана",
    "Enforce expiration date" : "Захтевај датум истека",
    "Allow resharing" : "Дозволи поновно дељење",
    "Restrict users to only share with users in their groups" : "Ограничи кориснике да могу да деле само унутар групе",
    "Exclude groups from sharing" : "Изузми групе из дељења",
    "These groups will still be able to receive shares, but not to initiate them." : "Ове групе ће моћи да примају дељења али не и да их праве.",
    "Tips & tricks" : "Савети и трикови",
    "How to do backups" : "Како правити резерве",
    "Advanced monitoring" : "Напредно праћење",
    "Performance tuning" : "Побољшање перформанси",
    "Improving the config.php" : "Побољшање фајла поставки",
    "Theming" : "Теме",
    "Hardening and security guidance" : "Ојачавање система и безбедносне препоруке",
    "Profile picture" : "Слика профила",
    "Upload new" : "Отпреми нову",
    "Remove image" : "Уклони слику",
    "Cancel" : "Одустани",
    "Full name" : "Пуно име",
    "No display name set" : "Није постављено име за приказ",
    "Email" : "Е-пошта",
    "Your email address" : "Ваша адреса е-поште",
    "No email address set" : "Није постављена е-адреса",
    "You are member of the following groups:" : "Имате чланство у следећим групама:",
    "Language" : "Језик",
    "Help translate" : " Помозите у превођењу",
    "Password" : "Лозинка",
    "Current password" : "Тренутна лозинка",
    "New password" : "Нова лозинка",
    "Change password" : "Измени лозинку",
    "Username" : "Корисничко име",
    "Done" : "Завршено",
    "Show storage location" : "Прикажи локацију складишта",
    "Show user backend" : "Прикажи позадину за кориснике",
    "Show email address" : "Прикажи е-адресу",
    "Send email to new user" : "Пошаљи е-пошту новом кориснику",
    "E-Mail" : "Е-пошта",
    "Create" : "Направи",
    "Admin Recovery Password" : "Администраторска лозинка за опоравак",
    "Enter the recovery password in order to recover the users files during password change" : "Унесите лозинку за опоравак корисничких фајлова током промене лозинке",
    "Everyone" : "Сви",
    "Admins" : "Администратори",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Унесите квоту складиштења (нпр. 512 MB или 12 GB)",
    "Unlimited" : "Неограничено",
    "Other" : "Друго",
    "Quota" : "Квота",
    "change full name" : "измени пуно име",
    "set new password" : "постави нову лозинку",
    "change email address" : "измени е-адресу",
    "Default" : "Подразумевано",
    "Enabled" : "Укључено",
    "Not enabled" : "Искључено",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Наведите администраторску лозинку опоравка. У супротном, сви кориснички подаци биће изгубљени.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Позадина не подржава измеу лозинке али кориснички шифрарски кључеви су успешно ажурирани.",
    "test email settings" : "тестирајте поставке е-поште",
    "Invalid request" : "Неисправан захтев",
    "Admins can't remove themself from the admin group" : "Администратор не може себе да уклони из admin групе",
    "Unable to add user to group %s" : "Не могу да додам корисника у групу %s",
    "Unable to remove user from group %s" : "Не могу да уклоним корисника из групе %s",
    "Sending..." : "Шаљем...",
    "Uninstalling ...." : "Деинсталирам ...",
    "Error while uninstalling app" : "Грешка при деинсталацији апликације",
    "Uninstall" : "Деинсталирај",
    "__language_name__" : "Српски",
    "Personal info" : "Лични подаци",
    "Sync clients" : "Синхронизовање клијената",
    "This is used for sending out notifications." : "Ово се користи за слање обавештења.",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "ПХП није подешен да може да провери системске променљиве. Проба са getenv(\"PATH\") враћа празан одговор.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "ПХП је очигледно подешен да се скида уметнуте док блокова. То ће учинити неколико кључних апликација недоступним.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Недостаје ПХП модул „fileinfo“. Препоручујемо вам да га укључите да бисте добили најбоље резултате с откривањем МИМЕ врста.",
    "This means that there might be problems with certain characters in file names." : "То значи да може доћи до проблема са неким знаковима у називима фајлова.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Препоручујемо да инсталирате потребне пакете да бисте подржали следеће локалитете: %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ако инсталација није инсталирана у основи домена и користи системски крон, може бити проблема са генерисањем веб адреса. Да бисте избегли ове проблеме, молимо вас да подесите \"overwrite.cli.url\" опцију у вашем  config.php фајлу у путању веб-основе ваше инсталације (Предложено: \"%s\")",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Није било могуће да се изврши крон задатак путем интерфејса командне линије. Појавила су се следеће техничке грешке:",
    "Cron" : "Крон",
    "Last cron job execution: %s." : "Последњи извршени крон задатак: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Последњи извршени крон задатак: %s. Нешто изгледа није у реду.",
    "Cron was not executed yet!" : "Крон задатак још увек није извршен!",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php је регистрован код  вебкрон сервиса за позивање cron.php сваких 15 минута преко протокола http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Користите системски крон сервис за позивање cron.php фајла сваких 15 минута.",
    "Cheers!" : "Здраво!",
    "Get the apps to sync your files" : "Преузмите апликације ради синхронизовања ваших фајлова",
    "Desktop client" : "Клијент за рачунар",
    "Android app" : "Андроид апликација",
    "iOS app" : "иОС апликација",
    "Show First Run Wizard again" : "Поново прикажи чаробњака за прво покретање",
    "Name" : "назив",
    "Show last log in" : "Прикажи последњу пријаву"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
